#
# spec file for package xreader
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   3
%define typelib1 typelib-1_0-XreaderDocument-1_5
%define typelib2 typelib-1_0-XreaderView-1_5
Name:           xreader
Version:        4.0.2
Release:        bp156.1.2
Summary:        Document viewer for documents like PDF/PostScript
License:        GPL-2.0-only AND LGPL-2.0-only
Group:          Productivity/Office/Other
URL:            https://github.com/linuxmint/xreader
Source:         https://github.com/linuxmint/xreader/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtiff-devel >= 3.6
BuildRequires:  mathjax
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  texlive-devel
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.17
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.6
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(libgxps) >= 0.2.0
BuildRequires:  pkgconfig(libsecret-1) >= 0.5
BuildRequires:  pkgconfig(libspectre) >= 0.2.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.5.0
BuildRequires:  pkgconfig(poppler-glib) >= 0.22.0
BuildRequires:  pkgconfig(sm) >= 1.0.0
BuildRequires:  pkgconfig(webkit2gtk-4.1) >= 2.4.3
BuildRequires:  pkgconfig(xapp) >= 1.1.0
BuildRequires:  pkgconfig(zlib)
# Only require pdf backend subpackage to make application more lightweight for Live media
Requires:       %{name}-plugin-pdfdocument
Recommends:     %{name}-lang
Provides:       %{name}-backends = %{version}
Provides:       caja-extension-%{name} = %{version}
Provides:       nemo-extension-%{name} = %{version}
Obsoletes:      %{name}-backends < %{version}
Obsoletes:      caja-extension-%{name} < %{version}
Obsoletes:      nemo-extension-%{name} < %{version}
%glib2_gsettings_schema_requires

%description
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%lang_package

%package -n libxreaderdocument%{sover}
Summary:        X-Apps Document Reader -- System Library
Group:          System/Libraries

%description -n libxreaderdocument%{sover}
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%package -n libxreaderview%{sover}
Summary:        X-Apps Document Reader -- System Library
Group:          System/Libraries

%description -n libxreaderview%{sover}
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%package -n %{typelib1}
Summary:        XReaderDocument -- Introspection Bindings
# typelib-1_0-XreaderDocument-1_5_0 was last used in openSUSE Leap 42.3.
Group:          System/Libraries
Provides:       typelib-1_0-XreaderDocument-1_5_0 = %{version}
Obsoletes:      typelib-1_0-XreaderDocument-1_5_0 < %{version}

%description -n %{typelib1}
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%package -n %{typelib2}
Summary:        XReaderView -- Introspection Bindings
# typelib-1_0-XreaderView-1_5_0 was last used in openSUSE Leap 42.3.
Group:          System/Libraries
Provides:       typelib-1_0-XreaderView-1_5_0 = %{version}
Obsoletes:      typelib-1_0-XreaderView-1_5_0 < %{version}

%description -n %{typelib2}
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%package devel
Summary:        X-Apps Document Reader development files
Group:          Development/Libraries/C and C++
Requires:       %{typelib1} = %{version}
Requires:       %{typelib2} = %{version}

%description devel
Xreader is a document viewer capable of displaying multiple and
single page document formats like PDF and Postscript.

%package -n xreader-plugin-epubdocument
Summary:        EPUB document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-epubdocument
A plugin for Xreader to read EPUB documents.

%package -n xreader-plugin-pdfdocument
Summary:        PDF document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-pdfdocument
A plugin for Xreader to read PDF documents.

%package -n xreader-plugin-psdocument
Summary:        PostScript document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-psdocument
A plugin for Xreader to read PostScript documents.

%package -n xreader-plugin-tiffdocument
Summary:        TIFF document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-tiffdocument
A plugin for Xreader to read TIFF documents.

%package -n xreader-plugin-xpsdocument
Summary:        XPS document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-xpsdocument
A plugin for Xreader to read XPS documents.

%package -n xreader-plugin-comicsdocument
Summary:        Comics document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-comicsdocument
A plugin for Xreader to read Comics documents.

%package -n xreader-plugin-djvudocument
Summary:        DjVu document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-djvudocument
A plugin for Xreader to read DjVu documents.

%package -n xreader-plugin-dvidocument
Summary:        DVI document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-dvidocument
A plugin for Xreader to read DVI documents.

%package -n xreader-plugin-pixbufdocument
Summary:        Pixbuf document support for Xreader
Group:          Productivity/Office/Other
Requires:       %{name}
Supplements:    %{name}

%description -n xreader-plugin-pixbufdocument
A plugin for Xreader to read Pixbuf documents.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
-Dintrospection=true \
-Ddjvu=true \
-Ddvi=true \
-Dt1lib=true \
-Dpixbuf=true \
-Dcomics=true \
-Dhelp_files=true

%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file -r %{name} GTK Office Viewer
%fdupes %{buildroot}%{_datadir}/

%post -n libxreaderview%{sover} -p /sbin/ldconfig

%postun -n libxreaderview%{sover} -p /sbin/ldconfig

%post -n libxreaderdocument%{sover} -p /sbin/ldconfig

%postun -n libxreaderdocument%{sover} -p /sbin/ldconfig

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post
%desktop_database_post
%mime_database_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_post
%desktop_database_postun
%mime_database_postun
%glib2_gsettings_schema_post
%endif

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-previewer
%{_bindir}/%{name}-thumbnailer
%{_datadir}/%{name}/
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/%{sover}/
%dir %{_datadir}/thumbnailers/
%{_libexecdir}/xreaderd
%{_datadir}/thumbnailers/%{name}.thumbnailer
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/xreader.appdata.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/help/C/%{name}
%{_mandir}/man?/*.?%{?ext_man}
# backends directory structure - backends go to their own packages
%dir %{_libdir}/%{name}/%{sover}/backends

%files lang -f %{name}.lang

%files -n libxreaderview%{sover}
%{_libdir}/libxreaderview.so.%{sover}*

%files -n libxreaderdocument%{sover}
%{_libdir}/libxreaderdocument.so.%{sover}*

%files -n %{typelib1}
%{_libdir}/girepository-1.0/XreaderDocument-1.5.typelib

%files -n %{typelib2}
%{_libdir}/girepository-1.0/XreaderView-1.5.typelib

%files devel
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_datadir}/gir-1.0/*.gir
%{_libdir}/pkgconfig/*.pc

%files -n xreader-plugin-epubdocument
%{_libdir}/%{name}/%{sover}/backends/epubdocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libepubdocument.so

%files -n xreader-plugin-pdfdocument
%{_libdir}/%{name}/%{sover}/backends/pdfdocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libpdfdocument.so

%files -n xreader-plugin-psdocument
%{_libdir}/%{name}/%{sover}/backends/libpsdocument.so
%{_libdir}/%{name}/%{sover}/backends/psdocument.xreader-backend

%files -n xreader-plugin-tiffdocument
%{_libdir}/%{name}/%{sover}/backends/tiffdocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libtiffdocument.so

%files -n xreader-plugin-xpsdocument
%{_libdir}/%{name}/%{sover}/backends/libxpsdocument.so
%{_libdir}/%{name}/%{sover}/backends/xpsdocument.xreader-backend

%files -n xreader-plugin-comicsdocument
%{_libdir}/%{name}/%{sover}/backends/comicsdocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libcomicsdocument.so

%files -n xreader-plugin-djvudocument
%{_libdir}/%{name}/%{sover}/backends/djvudocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libdjvudocument.so

%files -n xreader-plugin-dvidocument
%{_libdir}/%{name}/%{sover}/backends/dvidocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libdvidocument.so

%files -n xreader-plugin-pixbufdocument
%{_libdir}/%{name}/%{sover}/backends/pixbufdocument.xreader-backend
%{_libdir}/%{name}/%{sover}/backends/libpixbufdocument.so

%changelog
* Sun Jan 28 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.2 (CVE-2023-44451, bsc#1218298, CVE-2023-44452,
    bsc#1218299):
  * l10n: Update translations
  * Fix list of supported mime types (#631)
  * dependency: Drop compatibility with libwebkit2gtk-4.0
  * dvi: Don't manually escape the exported filename.
  * ev-window.c: Don't create the epub webview until the doc type
    is known.
  * Djvu file rotation direction fixed (#628)
  * epub: Prevent path traversal when extracting files
    [CVE-2023-44451]
  * comics: Use libarchive to unpack documents [CVE-2023-44452].
  * Revert "ev-window.c: Don't create the epub webview until the
    doc type"
  * l10n: Update translations
* Sun Dec  3 2023 Marguerite Su <i@marguerite.su>
- update to version 3.8.3
  * ev-message-area.c: Check that the GtkStockItem is initialized
  * ev-window.c: Only close after save-sas if it's spawned as a result
* Mon Aug 28 2023 Marguerite Su <i@marguerite.su>
- update to version 3.8.2
  * Add the window maximization setting to preferences
  * Add a setting to control window maximization on new documents
  * Background colour of presentation view fixed
  * ev-pixbuf-cache.c: Fix leak when rendering pages while annotating
  * Add support for AI mimetype
  * ps backend: disable pdf export using libspectre
  * ev-view.c: Check if there is a focused annotation before trying
    to access it
* Wed Nov  9 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.4.5
  * Allow adding Highlight annotations from text selection
  * Search: Add a close button
  * l10n: Update translations
  * epub: Fix index loading for certain documents - look for epub:type instead of epub:id.
  * epub: Free the document when we leave early because of a bad toc file.
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.3.0
  * Thumbnailer: Remove epub support, it's handled by xapp-epub-thumbnailer.
* Mon Jan 10 2022 Aaron Stern <ukbeast89@protonmail.com>
- Removed unused -Dbus option.
* Tue Jan  4 2022 andy great <andythe_great@pm.me>
- Update to version 3.2.2.
  * l10n: Update translations
- Update to version 3.2.1
  * Gsettings: Remove state schema reference
- Update to version 3.2.0
  * Add an option to hide the menu bar
  * Make show-toolbar a global setting
  * Update the README. (#498)
  * window: Don't show any toolbar in fullscreen
  * rtl: Fix arrow key navigation in mangas
  * metadata: Save the number of pages
  * Remove landing view
  * l10n: Update POT
- Update to version 3.0.2
  * l10n: Update translations
- Update to version 3.0.1
  * annotation icons added (#491)
  * attachment popup fix (#492)
  * l10n: Update translations
* Thu Jun  3 2021 andy great <andythe_great@pm.me>
- Update to version 3.0.0.
  * Fixes #457. Allows space bar to scroll document forward
  * Move metadata to non-legacy path
  * Fixes #463. Moves annotations below the text.
  * packaging: Fix metadata location.
  * Fixes #473. Jump to Page functionality
  * enter event on presentation mode
  * readme updated
  * show the total number of words matching the search result
  * fix segfault in epub backend when opening a filename containing a hash
  * epub: Fix unescaping of '#' (#487)
  * control+f and space behaviours fixed in search bar (#488)
  * Fix grammar error spotted by lintian (#489)
  * l10n: Don't include gsettings schema in translations
  * l10n: Update POT
* Fri Jan 29 2021 andy great <andythe_great@pm.me>
- Re-enable build for extensions.
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Update to version 2.8.3.
  * Fix Save a Copy issue with Firefox (#448)
* Sat Jan  2 2021 andy great <andythe_great@pm.me>
- Update to version 2.8.2.
  * Fix scrolling regressions
  * Add Right-to-Left support
  * l10n: Update POT
  * l10n: Update translations
* Thu Dec 17 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.1.
  * Convert parse_mimetypes from returning g_char** to void
  * l10n: Update translations
- Remove fix_no_return_statement_ev-application.c.patch, fixed.
- Fix RPMLINT warning W: obsolete-not-provided.
* Sun Dec  6 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.0.
  * Get toolbar visibility from GtkRevealer when saving view
    metadata
  * Add g_assert_not_reached to sizing_mode_to_string
  * setting to hide/show menubar (WIP)
  * Update menubar toggle action on init
  * fix saving menubar visibility as default
  * Added logic to fix issue of Tab key toggling checkboxes
  * Fix mimetype handling and backend selection:
  * Clean up build files
  * Fix for #89. Added logic to allow for cursor position to change
    in multiline-text fields
  * Added keyboard shortcut for toolbar
  * Fix for #442. Added null check to stop segfault with
    annotations
  * Implemented ticket #241. Added show sidebar button to toolbar
  * Move the new sidebar button to be part of the navigation group
    on the left end of the toolbar.
  * Added keyboard shortcuts to history buttons
  * Favorites - rework startup page to display both favorites and
    recents, add favorites to the file menu.
  * Disable pixbuf support properly.
  * ev-window.c: Temporarily disable menu toggling using the alt
    key.
  * Implements ticket #279. Added Go To Page By Number to menu
  * Displays entire label in tooltip
  * Revert "Implements ticket #279. Added Go To Page By Number to
    menu"
  * l10n: Fix po/POTFILES.in
  * ev-window-title.c: Don't show "Recent Documents" in the landing
    page titlebar - it is no longer showing only recents.
  * l10n: Update POT
- Removed fix_ev-window.c_error.patch, fixed.
- Add fix_no_return_statement_ev-application.c.patch to fix
  /shell/ev-application.c error no return statement in
  function returning non-void.
* Fri Sep 18 2020 andy great <andythe_great@pm.me>
- Update to version 2.6.4.
  * Fix app version.
- Update since 2.2.2.
  * l10n: Update translations
  * Fix compile warnings (#317)
  * Fix build: Fail on implicit function declarations (#321)
  * preview window/printing: Remove build conditionals for
    gtk+-unix-print-3.0
  * Fix segfault on empty navMap (#334)
  * meson: Dependency fixes (#335)
  * EVINCE BACKPORTS:
  * backends: backends: Don't ask for bug report
    in known issues. Fixes #695165
  * pdf: Create highlight annotations for existing annotations
    in document
  * libdocument: adding class EvAnnotationTextMarkup
  * libdocument: adding annotation highlight
  * shell: Show highlight annotations in the sidebar
  * libdocument: Use a common annotation type for text markup
    annotations
  * Add support for reading strike out text markup annotations
  * Add support for reading underline text markup annotations
  * Add support for changing the type of a text markup annotation
  * pdf: Fix memory leak when adding new text annotations
  * libdocument: Added can-have-popup property to
    EvAnnotationMarkups.
  * pdf: Set can-have-popup property to markup annotations when
    created
  * ev-view: Create an EvAnnotationWindow for
    EvAnnotationMarkups allowing this
  * pdf: Added support to save popup rectangles to pdf backend
  * pdf: Use poppler_annot_markup_set_popup_rectangle() if
    available
  * pdf: Force text annotations to have a fixed size 24x24
  * libview: Take border into account when converting view points
    to doc points
  * view: preparing for interactive annotations
  * libdocument: adding annotation squiggly.
  * pdf: adding annotation squiggly.
  * shell: adding annotation squiggly.
  * pdf: Fixed wrong type-check in copy_poppler_annot.
  * libdocument: Add area property to EvAnnotation
  * libview: Set the area of the annotations created by the user
  * pdf: Deprecate the rectangle passed to
    ev_document_annotations_add_annotation
  * libdocument: Add EV_ANNOTATIONS_SAVE_AREA flag
  * pdf: Add support for saving the annotation area
  * libview: Update the annot area while moved when it's being
    added
  * pdf: support for adding and saving highlight annotations
  * shell, view: adding highlight annotation
  * pdf: Ensure we always create text markup annots with at
    least one quadrilateral
  * Add a toolbar for adding annotations
  * page-cache: Add flags parameter to ev_page_cache_mark_dirty()
  * pdf: Mark document as modified when inserting annotations
  * libview: Do not create annotation window twice.
  * libview: Ignore right clicks while in annotation add mode.
  * view: use a hashtable to map annots to their popups.
  * ev-view: don't show tooltips for empty annotations
  * Fix add_annotation() to update area based on bounding box
  * Remove deprecated/unused code and fix warnings
  * libview: Hide annotation windows on key-press
  * l10n: Update POT
  * Meson: Formatting fix in the options file
  * Thumbnailer: Do not try to create an unsupported epub thumbnail
  * Thumbnailer: Remove MATE label from context
  * Add meson scripts for compiling gschemas and updating the icon
    cache
  * meson: Fix build configuration - dbus support was partly broken.
  * Shell: Run thumbnail jobs for epubs not as threads (#353)
  * meson: fix detection of t1lib
  * Created test for the Xreader Help menu.
  * Created test cases for File and Edit menus.
  * Remove use of deprecated g_type_class_add_private function
  * ev-window.c: Refactor action visibility.
  * ev-window.c: Hide the toolbar in recent document mode, there's
    nothing that can be used on it anyhow.
  * Created more tests for Xreader menu.
  * Tests: use build target rather than executable name for
    dependency
  * Build: change the conditions for handling tests
  * tests: Some adjustments and improvements
  * testEditMenu.py and testFileMenu.py: open file with arg to
    prevent error
  * Tests: extend the timeout from 30 seconds to 2 minutes
  * Updated old tests
  * meson: simplify version comparison
  * Updated python version to python3
  * ev-window.c: Don't use g_type_class_peek.
  * Added checks to stop error messages from overtaking the terminal
    and possibly causing a segfault.
  * Add Print button to toolbar
  * Added logic to keep the find bar visible until keyboard shortcut
    is pressed.
  * Added back hot keys
  * Fix Segmentation fault when opening a PDF file #339
  * Add UTF8 support for filename in recent view
  * Zoom by Control+scroll is too sensitive
  * [Feature request] Please provide "Save" option
  * Use new annotations icons (#397)
  * Fix xreader crash on epub search
  * Copy metadata when a file is copied
  * Thumbnailer: add application/vnd.comicbook-rar
- Add patch fix_ev-window.c_error.patch to
  fix error: control reaches end of non-void function.
* Sat Nov  9 2019 Marguerite Su <i@marguerite.su>
- Remove Requires: xreader-backends from xreader-devel
* Sun Aug 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
-  Restore backend subpackages accidentally removed by previous Jul 8
  SR:
  - Split backends into subpackages to prevent hard dependency
    to backends and make application more lightweight
  - Dropped xreader-backends package (obsolete)
* Sun Jul 28 2019 Marguerite Su <i@marguerite.su>
- Update to version 2.2.2:
  * libview: Allow printing to all formats supported by backend
  * fix #239 Printing issue: Incorrect centering while printing
* Mon Jul  8 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.1:
  * Remove patch xreader-fix-func-type.patch is no longer needed
  * meson: Fix libexec (#319)
  * build: Fix gir package
  * Fix some warnings when building xreader 2.0.2 (#265)
  * CI: Remove Mint 18
  * port to meson (#269)
  * Build: Fix Debian Stretch build
  * Take device scale factor into account for zoom (#277)
  * Update readme for meson changes (#284)
  * meson: change 'debug' option to 'enable_debug' to avoid collisions (#285)
  * Remove leftover code
  * view: Fix whitespace issues
  * ev-window: Fix incompatible pointer type issues
  * ATRIL BACKPORTS: a11y: Do not use AtkFactory to create the EvViewAccessible
  * ATRIL BACKPORTS: libview: Rename EvView coordinate transformation functions
  * ATRIL BACKPORTS: ev-view-accessible: Use _ev_view_transform_view_point_to_doc_point()
  * ATRIL BACKPORTS: ev-view-accessible: Use _ev_view_transform_doc_rect_to_view_rect()
  * ATRIL BACKPORTS: ev-view: Inlcude ev-jobs in ev-view.h
  * ATRIL BACKPORTS: libdocument: Add length and nth methods to EvMappingList
  * ATRIL BACKPORTS: libview: Implement AtkHypertext interface
  * ATRIL BACKPORTS: libview: Make EvLinkAccessible implement AtkAction
  * ATRIL BACKPORTS: ev-view-accessible: Add helper function to get text before, at or after offset
  * ATRIL BACKPORTS: ev-view-accessible: Fix some coding style issues
  * Meson fixups (#293)
  * libdocument: Fix handling of mime-type aliases (#292)
  * ATRIL BACKPORTS: Add missing comma.
  * sidebar-thumbnails: clean up cancel_running_jobs
  * ATRIL BACKPORTS: sidebar-thumbnails: preload one extra visible range while scrolling
  * ATRIL BACKPORTS: EvPixbufCache: Handle backends that don't render a selection
  * Fix some compile time warnings
  * EVINCE BACKPORTS: libview: Reset `pressed_button` when starting Drag and Drop (#301)
  * build: Fix compiling with disabled epub (#308)
  * Fix text selection in HiDPI (#302)
  * Add optional zoom level selector. (#305)
  * epub backend: make mathjax directory a configure-time option (#297)
  * Make help files optional (#311)
  * shell: Add a ctrl+q shortcut to close all open windows (#312)
  * shell: Add a 'No recent documents' screen (#313)
  * EVINCE BACKPORTS: shell: forward accels to the focused widget (#315)
  * l10n: Update POT
  * Build: Fix l10n
  * libdocument: Return default DPI on failure (#316)
  * xreaderd logging (#318)
* Wed Mar 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed Obsoletes xreader-backends
* Tue Mar 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Split backends into subpackages to prevent hard-dependency
  build failures
- Dropped xreader-backends package
* Fri Jul 20 2018 sor.alexei@meowr.ru
- Update to version 1.8.5:
  * Fix thumbnail creation.
  * sidebar-thumbnails: Fix clunky scrolling.
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.4:
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.8.3:
  * Fix a crash in libpdfdocument when opening a specific PDF.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.2:
  * Update translations.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.8.1 (changes since 1.6.2):
  * Bump xapp requirement to 1.1.0
  * Add Remove Annotation.
  * Correct sidebar refresh after removing annotation.
  * Code style: Fix ev-application and ev-window.
  * shell: Use g_printerr instead of g_warning
  * shell: Port to GtkApplication.
  * daemon: Port to GApplication.
  * Recent view.
  * Add a preferences dialogue and optional toolbar buttons.
  * Fix Ctrl+A selecting the entire document when focus is on a
    text entry.
  * ev-recent-view: General cleanup.
  * Sidebar: Add a close button.
  * Fix crash when opening an already open document twice.
  * Fix Epub thumbnails.
  * Allow to save epub documents.
  * Add the ability to zoom in/out thumbnails.
  * Add smooth scrolling.
  * Thumbnail zoom buttons: Reorder, use symbolic and rename the
    tooltips.
  * Fix changing page in Page View after zooming out.
  * ev-sidebar: Don't set the relief on the select button to NONE.
  * Bug fixes.
  * Add a shortcut for continuous mode.
  * Remove caja/nemo extensions.
- Add xreader-fix-func-type.patch: Fix function type to fix a
  warning in libview/ev-view.c.
- Drop packages for Caja and Nemo extensions.
* Sun Dec 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.2:
  * configure.ac: Use a major.minor version only for API, this
    broke loading of introspection otherwise, which seems to expect
    only the *-1.5.typelib.
  * Fix searching for a word that is a continuation of a
    non-existent word (gh#linuxmint/xreader#135).
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.1:
  * Update translations.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.6.0:
  * Document that libcaja-extension is required.
  * ATRIL BACKPORTS: comics: Make the files containing
    "--checkpoint-action=" unsupported (#158)
  * previewer: Use GResource for data files.
  * shell: Use GResource for data files.
  * Move custom css to a file compiled as a gresource.
  * ev-view: Fix the Eview background colour, page borders and
    shadow.
  * Fix too bright selection colour during opened context menu.
  * Revert "sometimes info->linearized is not a string" and
    "crash on g_free the address 0 or 1".
  * Avoid deprecated gtk_misc_set_alignment.
  * zoom-control.c: Don't use deprecated
    gtk_combo_box_set_focus_on_click.
  * docs: Add missing EvAnnotation API to sections.txt.
  * eggfindbar: Don't use deprecated GtkAlignment.
  * password-view: Don't use deprecated GtkAlignment.
  * password-view: Replace some GtkStock deprecations.
  * message-area: Replace some GtkStock deprecations.
  * ev-view: Avoid deprecated gtk_drag_begin.
  * shell: Remove unused code from utils.
  * build: Require cairo >= 1.14.0 and drop some old code.
  * Switch zoom buttons in toolbar.
  * Add zoom reset.
  * Move history actions from toolbar to Go menu, bring back
    navigation buttons in the toolbar.
  * Fix typo in previous commit.
  * shell: Use gdbus-codegen for the org.x.reader.Application
    interface.
  * shell: Use gdbus-codegen for the org.x.reader.Window interface.
  * daemon: Use gdbus-codegen for the org.x.reader.Daemon
    interface.
  * Make 100%% zoom level be real life size.
  * Update translations.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.4.4:
  * Update translations.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 1.4.3:
  * shell: Make main window title translatable
    (gh#linuxmint/xreader#39).
  * Fix "Having selected text leads to high cpu load".
  * Fix for "Inverted Colours won't be saved by Save Current
    Settings as Default"
  * Build: Remove unnecessary ev_get_locale_dir().
  * Branding: Use a generic application name.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * Fix gtk-doc with no Caja or no Nemo extension building.
  * Update translations.
- Remove xreader-fix-nocaja-build.patch: merged upstream.
* Wed May 10 2017 jengelh@inai.de
- Update descriptions from current homepage
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.1 (changes since 1.2.2):
  * Documentation: Add INSTALL, update README.
  * document-model: Make dual mode and dual mode odd page left
    mutally exclusive.
  * Split dual mode option into dual mode with odd and even pages
    on the left.
  * Fix case sensitive searching for PDF.
  * Bump poppler version requirement to 0.22.0.
  * comics: Properly open files with special characters in path.
  * comics: Fix MIME type comparisons.
  * comics: Support application/vnd.comicbook+zip MIME type.
  * djvu: Remove unneeded assignment.
  * tiff: Use function from cairo >= 1.6 unconditionally.
  * Add some missing contextual information for translators.
  * djvu: Support the image/vnd.djvu+multipage MIME type.
  * thumbnailer: Skip epub files.
  * Removed deprecated GTK_POLICY_AUTOMATIC.
  * Fix a crash when running with the Broadway Gdk backend.
  * ev-window.c: Remove some gtk version checks.
  * ev-window: Swap out the EggEditable toolbar for a normal
    toolbar.
  * Convert all icons to symbolics.
  * Tweak the fullscreen tool bar to match the style of the main
    tool bar a bit better.
  * annotation-window: Fix the sizes of close and resize icons.
  * build: --disable-caja and --disable-nemo are no longer ignored.
  * libdocument: Add deprecation macros.
  * libdocument: Use the new deprecation macros.
  * libdocument: Add EvAnnotation API using GdkRGBA.
  * shell: Use GdkRGBA for annotations.
  * ev-annotation: Use correct variable names in function prototype.
  * libview: Don't change the font colour of the annotation window.
  * libview: Fix focus on ev_annotation_window.
  * libview: fix annotation window focus change after creation.
  * ev-view: Add pinch/zoom gesture to handle document zooming.
  * ev-view: explicitly require a GtkScrolledWindow as the parent
    widget.
  * ev-view: Add pan gesture to switch page.
  * libview: Ctrl+mouse wheel zoom should be pointer-centred, not
    window-centred.
  * Remove unneeded pkgconfig checks.
  * ev-annotation-window: Fix setting the colour of the window
    border.
  * annotation-properties-dialog: Don't use a header bar.
  * Add a new EvToolbar.
  * ev-window.c: Simplify an if/else.
  * shell: Remove metadata migration code.
  * annotations-sidebar: Clean up the styling.
  * bookmarks-sidebar: Clean up the styling.
  * ev-sidebar: Do a bit of restyling.
  * sidebar-layers: Make it actually usable.
  * ev-page-action-widget: Allow changing pages with mouse wheel
    scrolling.
  * ev-page-action-widget: Update the page number when unfocused.
  * shell: Replace deprecated function call inside the GTK+3 code
    block.
  * cut-n-paste: Set vertical box to be homogeneous in the GTK+3
    code too.
  * ev-view: Properly declare a function.
  * shell: Ditch gimpcellrenderertoggle.
  * toolbar: Make further improvements.
  * Fix for bug #92: Segfault if djvu file gets clicked/moved.
  * djvu: Make empty pages white.
  * djvu: Use dpi of pages to compute scaling factor.
  * djvu: Enable selection highlighting.
  * comics backend: Add support for unarchiver (unar and lsar).
  * Force the X11 Gdk backend.
  * First page should not reloaded.
  * Previously opened page incorrectly restored if it was the last
    one.
  * Remove the GTK+2 code.
  * l10n: Update POT file.
  * Update translations.
- Add xreader-fix-nocaja-build.patch: Fix building with no Caja.
* Wed Mar 29 2017 sor.alexei@meowr.ru
- Add the missing Gtk2 build dependency.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Update translations.
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Update translations.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * See /usr/share/doc/packages/xreader/changelog
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.8:
  * Fix not saving changes to a dropdown in an embedded form.
  * Remove pixbuf from list of menu keywords.
  * Update translations.
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Update to version 1.0.7:
  * Fix Presentation and Zoom buttons greyed out, if no document
    has been loaded.
  * Show application name in about dialog.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Update translations.
* Tue May 17 2016 sor.alexei@meowr.ru
- Update to version 1.0.5 (changes since 1.0.3):
  * Fix segfault when opening properties of a PDF file (from the
    reader).
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.3 (changes since 1.0.1):
  * Remove Nemo extension .la files.
  * Don't use gi typelibdir for nemo extension path, use
    libnemo-extension libdir instead.
  * Fix WebKit detection.
  * Fix wrong return type in ev-page-action-widget.c.
  * Update translations.
- Remove xreader-fix-epub.patch, xreader-fix-func-decl.patch: merged
  upstream.
* Wed Feb 10 2016 sor.alexei@meowr.ru
- Initial package, based on atril's package.
